==> tuia-advert-center-api-2.0.0-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/data/AdvertPackageDayData.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.data;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Created by huangch on 2018/9/13 14:56
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertPackageDayData extends AdvertTransformBaseData {

    private static final long serialVersionUID = -5046891365990515095L;

    private Long packageId;

    private Long appId;

    private Float costChange;

    private Float effectCostFloat;

    //前3日成本均值
    private BigDecimal beforeThreeDaysAvgCost;

    //媒体状态
    private Integer appStatus;

    private List<String> appTags;

    private String appName;

    private Integer appSource;

    private Date curDate;

    //0-查询、1-导出
    private Integer type;

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public List<String> getAppTags() {
        return appTags;
    }

    public void setAppTags(List<String> appTags) {
        this.appTags = appTags;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public BigDecimal getBeforeThreeDaysAvgCost() {
        return beforeThreeDaysAvgCost;
    }

    public void setBeforeThreeDaysAvgCost(BigDecimal beforeThreeDaysAvgCost) {
        this.beforeThreeDaysAvgCost = beforeThreeDaysAvgCost;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public Float getCostChange() {
        return costChange;
    }

    public Float getEffectCostFloat() {
        return effectCostFloat;
    }

    public void setEffectCostFloat(Float effectCostFloat) {
        this.effectCostFloat = effectCostFloat;
    }

    public void setCostChange(Float costChange) {
        this.costChange = costChange;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }
}

==> tuia-advert-center-api-2.2.18-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/data/AdvertPackageDayData.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.data;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Created by huangch on 2018/9/13 14:56
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertPackageDayData extends AdvertTransformBaseData {

    private static final long serialVersionUID = -5046891365990515095L;

    private Long packageId;

    private Long appId;

    private Float costChange;

    private Float effectCostFloat;

    //前3日成本均值
    private BigDecimal beforeThreeDaysAvgCost;

    //媒体状态
    private Integer appStatus;

    private List<String> appTags;

    private String appName;

    private Integer appSource;

    private Date curDate;

    //0-查询、1-导出
    private Integer type;

    private String ifAddLimitApp;

    private String ifRmLimitApp;


    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public List<String> getAppTags() {
        return appTags;
    }

    public void setAppTags(List<String> appTags) {
        this.appTags = appTags;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public BigDecimal getBeforeThreeDaysAvgCost() {
        return beforeThreeDaysAvgCost;
    }

    public void setBeforeThreeDaysAvgCost(BigDecimal beforeThreeDaysAvgCost) {
        this.beforeThreeDaysAvgCost = beforeThreeDaysAvgCost;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public Float getCostChange() {
        return costChange;
    }

    public Float getEffectCostFloat() {
        return effectCostFloat;
    }

    public void setEffectCostFloat(Float effectCostFloat) {
        this.effectCostFloat = effectCostFloat;
    }

    public void setCostChange(Float costChange) {
        this.costChange = costChange;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public String getIfAddLimitApp() {
        return ifAddLimitApp;
    }

    public void setIfAddLimitApp(String ifAddLimitApp) {
        this.ifAddLimitApp = ifAddLimitApp;
    }

    public String getIfRmLimitApp() {
        return ifRmLimitApp;
    }

    public void setIfRmLimitApp(String ifRmLimitApp) {
        this.ifRmLimitApp = ifRmLimitApp;
    }
}
